﻿using System;
using System.Collections.Generic;
using System.IO;

namespace mosaic {
    class ColourManager {
        private readonly HashSet<Colour> colours = new HashSet<Colour>();

        /// <summary>
        /// Ctor, reads colours from the given file, where they should be
        /// in hexadecimal RGBA format.
        /// </summary>
        /// <param name="fi">The file containing the colour values</param>
        public ColourManager(FileInfo fi) {
            using (StreamReader sr = new StreamReader(fi.FullName)) {
                string temp;
                while ((temp = sr.ReadLine()) != null) {
                    string colour = temp.Split(' ')[0];
                    int rgba = Convert.ToInt32(colour, 16);
                    AddColour(new Colour(rgba));
                }
            }
        }

        /// <summary>
        /// Adds a colour to the stored colours
        /// </summary>
        /// <param name="c">The colour to add</param>
        public void AddColour(Colour c) {
            colours.Add(c);
        }

        /// <summary>
        /// Returns the stored colour that's closest to the given colour.
        /// </summary>
        /// <param name="colour">The given colour</param>
        /// <returns>The closest match found</returns>
        public Colour GetClosestStoredColour(Colour colour) {
            double minDist = double.MaxValue;
            Colour minColour = null;

            foreach (Colour c in colours) {
                double dist = colour.GetDistanceFrom(c);

                if (dist < minDist) {
                    minColour = c;
                    minDist = dist;
                }
            }

            return minColour;
        }
    }
}
