﻿using System;
using System.Drawing;
using System.Windows.Forms;
using mosaic.Properties;

namespace mosaic {
    public partial class MainForm : Form {
        public MainForm() {
            InitializeComponent();

            tbScale.Text = mosaicDisplay1.Scale.ToString();
            tbSquareSize.Text = mosaicDisplay1.Square.ToString();

            mosaicDisplay1.OpenImage("example.jpg");
        }

        #region Menu item handlers

        private void openToolStripMenuItem_Click(object sender, EventArgs e) {
            OpenFileDialog ofg = new OpenFileDialog();
            ofg.Filter = Resources.open_formats;
            if (ofg.ShowDialog() == DialogResult.OK) {
                mosaicDisplay1.OpenImage(ofg.FileName);
            }
        }

        private void saveImageToolStripMenuItem_Click(object sender, EventArgs e) {
            SaveFileDialog svd = new SaveFileDialog();
            svd.FileName = "mosaic.png";
            svd.DefaultExt = "png";
            svd.Filter = Resources.save_formats;

            if (svd.ShowDialog() == DialogResult.OK) {
                Bitmap bmp = mosaicDisplay1.GetBitMap();
                bmp.Save(svd.FileName);
                bmp.Dispose();
            }
        }

        private void exitToolStripMenuItem_Click(object sender, EventArgs e) {
            Close();
        }

        private void loadCustomPaletteToolStripMenuItem_Click(object sender, EventArgs e) {
            OpenFileDialog ofg = new OpenFileDialog();
            ofg.Filter = "Text files (.txt)|*.txt";
            if (ofg.ShowDialog() == DialogResult.OK) {
                mosaicDisplay1.LoadPalette(ofg.FileName);
            }
        }

        private void resetToDefaultToolStripMenuItem_Click(object sender, EventArgs e) {
            mosaicDisplay1.LoadPalette(null);
        }

        private void aboutToolStripMenuItem_Click(object sender, EventArgs e) {
            AboutDialog aboutDialog = new AboutDialog();
            aboutDialog.ShowDialog();
        }

        #endregion

        #region Button click handlers

        private void bZoomIn_Click(object sender, EventArgs e) {
            mosaicDisplay1.ZoomIn();
        }

        private void bZoomOut_Click(object sender, EventArgs e) {
            mosaicDisplay1.ZoomOut();
        }

        private void bSquareSizeUp_Click(object sender, EventArgs e) {
            mosaicDisplay1.DecreaseRes();
        }

        private void bSquareSizeDown_Click(object sender, EventArgs e) {
            mosaicDisplay1.IncreaseRes();
        }

        #endregion

        #region Textbox keypress handlers

        private void tbSquareSize_KeyDown(object sender, KeyEventArgs e) {
            if (e.KeyCode != Keys.Enter) {
                return;
            }

            try {
                int newSize = int.Parse(tbSquareSize.Text);
                mosaicDisplay1.Square = newSize;
            }
            catch (Exception exc) {
                Console.Error.WriteLine("Invalid square size entered");
                tbSquareSize.Text = mosaicDisplay1.Square.ToString();
            }
        }

        private void tbScale_KeyDown(object sender, KeyEventArgs e) {
            if (e.KeyCode != Keys.Enter) {
                return;
            }

            try {
                int newScale = int.Parse(tbScale.Text);
                mosaicDisplay1.Scale = newScale;
            }
            catch (Exception exc) {
                Console.Error.WriteLine("Invalid scale value entered");
                tbScale.Text = mosaicDisplay1.Scale.ToString();
            }
        }

        #endregion

        #region Change callback functions

        private void UpdateSquareSizeText(int squareSize) {
            tbSquareSize.Text = squareSize.ToString();
        }

        private void UpdateScaleText(double scale) {
            tbScale.Text = scale.ToString();
        }

        #endregion
    }
}
