﻿using System;
using System.Drawing;

namespace mosaic {
    class MosaicSquare : IDisposable {
        private int x, y, size;

        private Brush brush;

        /// <summary>
        /// Ctor
        /// </summary>
        /// <param name="c">Colour of the square</param>
        /// <param name="x">Horizontal position in pixels</param>
        /// <param name="y">Vertical position in pixels</param>
        /// <param name="size">Side length of the square in pixels</param>
        public MosaicSquare(Colour c, int x, int y, int size) {
            Color color = Color.FromArgb(c.R, c.G, c.B);
            brush = new SolidBrush(color);

            this.x = x;
            this.y = y;
            this.size = size;
        }

        /// <summary>
        /// Paints the square using the given Graphics object
        /// </summary>
        /// <param name="g">The Graphics object to use</param>
        /// <param name="scale">Scaling factor</param>
        public void Paint(Graphics g, double scale) {
            g.FillRectangle(
                brush,
                (int) (x*scale),
                (int) (y*scale),
                (int) (size*scale),
                (int) (size*scale));
        }

        /// <summary>
        /// Disposes the brush that the square used to paint itself
        /// </summary>
        public void Dispose() {
            brush.Dispose();
        }
    }
}
